---
layout: model
title: Fastext Word Embeddings in German
author: John Snow Labs
name: w2v_cc_300d
class: WordEmbeddingsModel
language: de
repository: clinical/models
date: 2020-09-06
task: Embeddings
edition: Healthcare NLP 2.5.5
spark_version: 2.4
tags: [embeddings, de, licensed]
supported: true
article_header:
type: cover
use_language_switcher: "Python-Scala-Java"
---

{:.h2_title}
## Description
Word Embeddings lookup annotator that maps tokens to vectors.

{:.btn-box}
<button class="button button-orange" disabled>Live Demo</button>
[Open in Colab](https://colab.research.google.com/github/JohnSnowLabs/spark-nlp-workshop/blob/master/tutorials/Certification_Trainings/Healthcare/14.German_Healthcare_Models.ipynb){:.button.button-orange.button-orange-trans.co.button-icon}[Download](https://s3.amazonaws.com/auxdata.johnsnowlabs.com/clinical/models/w2v_cc_300d_de_2.5.5_2.4_1599428063692.zip){:.button.button-orange.button-orange-trans.arr.button-icon.hidden}
[Copy S3 URI](s3://auxdata.johnsnowlabs.com/clinical/models/w2v_cc_300d_de_2.5.5_2.4_1599428063692.zip){:.button.button-orange.button-orange-trans.button-icon.button-copy-s3}
{:.h2_title}
## How to use 
<div class="tabs-box" markdown="1">

{% include programmingLanguageSelectScalaPythonNLU.html %}

```python
model = WordEmbeddingsModel.pretrained("w2v_cc_300d","de","clinical/models")\
	.setInputCols(["document","token"])\
	.setOutputCol("word_embeddings")
```

```scala
val model = WordEmbeddingsModel.pretrained("w2v_cc_300d","de","clinical/models")
	.setInputCols(Array("document","token"))
	.setOutputCol("word_embeddings")
```


{:.nlu-block}
```python
import nlu
nlu.load("de.embed.w2v").predict("""Put your text here.""")
```

</div>

{:.h2_title}
## Results
Word2Vec feature vectors based on ``w2v_cc_300d``.

{:.model-param}
## Model Information

{:.table-model}
|---------------|---------------------|
| Name:          | w2v_cc_300d         |
| Type:   | WordEmbeddingsModel |
| Compatibility: | Healthcare NLP 2.5.5+               |
| License:       | Licensed            |
| Edition:       | Official          |
|Input labels:        | [document, token]     |
|Output labels:       | [word_embeddings]     |
| Language:      | de                  |
| Dimension:    | 300.0               |

{:.h2_title}
## Data Source
FastText common crawl word embeddings for Germany
https://fasttext.cc/docs/en/crawl-vectors.html